Suite Examples
--------------

.. automodule:: nas_parallel_benchmark
    :members:
    :undoc-members:
    :show-inheritance:


**The Source:**

.. literalinclude:: ../../benchpress/suites/nas_parallel_benchmark.py
    :language: python
